# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-06-14 20:26
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('assignment_desk', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='week',
            name='role_type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='assignment_desk.RoleType'),
        ),
    ]
