<!DOCTYPE html>
{% load bootstrap3 static %}

<html{% if LANGUAGE_CODE %} lang="{{ LANGUAGE_CODE }}"{% endif %}>
    <head>
        <meta charset="utf-8">

        <title>{% block html_title %}Assignment desk{% endblock %}</title>

        <!--[if IE]><meta http-equiv="X-UA-Compatible" content="IE=edge" /><![endif]-->
        <meta name="viewport" content="width=device-width, initial-scale=1">

        {% block stylesheets %}
        <link rel="stylesheet" href="{% static 'assignment_desk/css/main.css' %}" />
        {% endblock %}
    </head>

    <body class="{% block body_class %}default{% endblock %}">
        {% block navbar %}
        <header class="navbar fixed-top navbar-toggleable-md navbar-dark double-nav scrolling-navbar top-nav-collapse {% block nav_class %}{% endblock %}">
            <div class="left-group">
                {% block left_nav_buttons %}
                <div class="home-nav left-button">
                    <a href="{% block back_nav_link %}{% endblock %}"><i class="material-icons md-24">arrow_back</i></a>
                </div>
                {% endblock %}
                <h4 class="navbar-brand" href="#">{% block nav_header %}Assignment desk{% endblock %}</h4>
            </div>

            <div class="right-buttons">
                {% block right_nav_buttons %}
                <div class="show-feed right-button">
                    <i class="material-icons md-24">history</i>
                </div>
                {% endblock %}
                {% comment %}
                <div class="show-nav right-button">
                    <button href="javascript:;" class="header-burger">
                        <span></span>
                        <span></span>
                        <span></span>
                    </button>
                </div>
                {% endcomment %}
            </div>
        </header>
        {% endblock %}

        <div class="collapsible-nav">
            <ul class="nav-items">
                <li><a href="{% url 'editorial_staff:staffer-list' %}">Staff management home</a></li>
                <li><a href="{% url 'editorial_staff:staffer-create' %}">Add new staffer</a></li>
                {% comment %}<li><a href="">Help</a></li>{% endcomment %}
                <li><a href="{% url 'apiauth:logout' %}">Log out</a></li>
            </ul>
        </div>

        <main class="{% block main_class %}{% endblock %}">
            <div class="scrollable">
                <div class="gutters">
                    {% block content %}
                        {% block content_above_list %}{% endblock %}
                    <ul class="tight-list">
                        {% block content_inner %}
                        {% endblock %}
                    </ul>
                    {% endblock %}
                </div>
            </div>

            {% block main_extra %}{% endblock %}
        </main>

        {% block extra_body %}{% endblock %}

        <section id="snackbars">{% block snackbars %}{% endblock %}</section>

        {% block scripts %}
        <script src="{% static 'assignment_desk/js/main.js' %}"></script>
        {% endblock %}
    </body>
</html>
