@charset "UTF-8";
/*!
 * Pikaday
 * Copyright Ã‚Â© 2014 David Bushell | BSD & MIT license | http://dbushell.com/
 */

.pika-single {
    border: 0px;
    color: #333;
    display: block;
    font-family: 'Roboto', sans-serif;
    font-size: 16px;
    font-weight: 400;
    line-height: 1.5;
    pointer-events: none;
    position: relative;
    z-index: 9999;
}

/*
clear child float (pika-lendar), using the famous micro clearfix hack
http://nicolasgallagher.com/micro-clearfix-hack/
*/

.pika-single:before,
.pika-single:after {
    content: " ";
    display: table;
}

.pika-single:before {
    background-color: rgba(0,0,0,0.3);
    content: '';
    display: block;
    height: 100%;
    left: 0;
    position: absolute;
    top: 0;
    width: 100%;
    z-index: -1;
}

.pika-single:after {
    clear: both;
}

.pika-single {
    *zoom: 1;
}

.pika-single.is-hidden {
    display: none;
}

.pika-single {
    bottom: 0 !important;
    left: 0 !important;
    // left: calc((100vw - 270px) / 2) !important;
    position: fixed;
    right: 0 !important;
    top: 0 !important;
    // top: calc((100vh - 324px) / 2) !important;
    // margin-left: -135px;
}

.pika-pika {
    background-color: transparent;
    transition: background-color .26s ease;
    position: fixed !important;
    top: 0 !important;
    bottom: 0;
    left: 0 !important;
    right: 0;
}

.pika-lendar {
    background-color: #fff;
    box-shadow: 0 5px 15px -5px rgba(0, 0, 0, 0.9);
    margin: calc((100vh - 324px) / 2) auto;
    padding: 0 0 15px 0;
    pointer-events: all;
    position: relative;
    transition: all .26s ease;
    width: 270px;
}

.im-here .pika-lendar {
    margin-top: 10%;
}

.im-here .pika-pika {
    background-color: rgba(0, 0, 0, 0.15);
}

.pika-title {
    position: relative;
    text-align: center;
    background-color: #566dd1;
    padding: 27px 19px 13px;
    overflow: hidden;
}

.pika-label {
    display: inline-block;
    *display: inline;
    position: relative;
    z-index: 9999;
    margin: 0;
    font-weight: 400;
    color: #fff;
    background-color: transparent;
}

.pika-label.dayname {
    display: block;
    background-color: #425ccc;
    margin: -27px -19px 16px;
    padding: 4px;
}

.pika-label.day {
    display: block;
    font-size: 50px;
    line-height: 50px;
    padding: 0;
    width: 80px;
    margin: 0 auto;
}

.pika-label.month {
    text-transform: uppercase;
    font-size: 20px;
    line-height: 20px;
    padding: 0;
}

.pika-label.year {
    font-size: 20px;
    line-height: 20px;
    padding: 0;
    color: #a6b2e7;
}

.pika-title select {
    cursor: pointer;
    position: absolute;
    z-index: 9998;
    margin: 0;
    left: 0;
    top: 5px;
    filter: alpha(opacity=0);
    opacity: 0;
}

.pika-prev,
.pika-next {
    display: block;
    cursor: pointer;
    position: absolute;
    top: 0;
    outline: none;
    border: 0;
    padding: 0;
    width: 34px;
    height: 100%;
    text-indent: 68px;
    white-space: nowrap;
    overflow: hidden;
    background-color: transparent;
    *position: absolute;
    *top: 0;
    transition: opacity .26s ease;
    opacity: .3;
}

.pika-prev:hover,
.pika-next:hover {
    opacity: .8;
}

.pika-prev:hover,
.pika-next:hover {
    opacity: 1;
}

.pika-prev {
    left: 0;
}

.pika-next {
    right: 0;
}

.pika-prev:before,
.pika-next:before {
    content: " ";
    border-color: #fff;
    border-style: solid;
    width: 10px;
    height: 10px;
    display: block;
    position: absolute;
    top: calc( 50% + 9px);
    -webkit-transform: rotate(45deg);
    -ms-transform: rotate(45deg);
    transform: rotate(45deg);
}

.pika-prev:before {
    border-width: 0 0 2px 2px;
    left: 20px;
}

.pika-next:before {
    border-width: 2px 2px 0 0;
    right: 20px;
}

.pika-prev,
.is-rtl .pika-next {
    float: left;
    *left: 0;
}

.pika-next,
.is-rtl .pika-prev {
    float: right;
    *right: 0;
}

.pika-prev.is-disabled,
.pika-next.is-disabled {
    cursor: default;
    opacity: .2;
}

.pika-select {
    display: inline-block;
    *display: inline;
}

.pika-table {
    width: auto !important;
    border-collapse: collapse;
    border-spacing: 0;
    border: 0;
    margin: 0 15px 15px 15px;
}

.pika-table th,
.pika-table td {
    width: 14.285714285714286%;
    padding: 0;
}

.pika-table th {
    color: #454545;
    font-size: 12px;
    line-height: 25px;
    font-weight: normal;
    text-align: center;
    padding: 10px 0px;
}

.pika-button {
    cursor: pointer;
    display: block;
    box-sizing: border-box;
    -moz-box-sizing: border-box;
    outline: none;
    border: 0;
    margin: 0 2px 7px;
    width: 30px;
    height: 30px;
    padding: 0;
    color: #444;
    font-size: 12px;
    line-height: 15px;
    background-color: #FFFFFF;
    text-align: center;
    border-radius: 100%;
}

.pika-footer {
    text-align: right;
}

.pika-ok {
    border: 0;
    background-color: transparent;
    font-weight: 700;
    text-transform: uppercase;
    font-size: 16px;
    padding: 6px 10px;
    margin: 0 25px;
    color: #566dd1;
}

.pika-ok:focus,
.pika-ok:active {
    outline: 0;
}

.pika-week {
    font-size: 11px;
    color: #444;
}

.is-today .pika-button {
    color: #566dd1;
    font-weight: bold;
}

.is-selected .pika-button {
    color: #fff;
    font-weight: bold;
    background-color: #566dd1;
    border-color: #fff !important;
}

.is-disabled .pika-button {
    pointer-events: none;
    cursor: default;
    color: #666;
    opacity: .3;
}

.pika-button:hover {
    color: #fff !important;
    background: #566dd1 !important;
    border-color: #fff !important;
}

/* styling for abbr */

.pika-table abbr {
    border-bottom: none;
    cursor: default;
}

.pika-table {
    border: none;
}

.pika-table td,
.pika-table tr,
.pika-table th {
    border: none;
}
